@@ -12,7 +12,7 @@ use crate::game::State;
 use crate::image::Image;
 
 pub const VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
-pub const AUTHOR: &str = "(c) Jens Getreu, 2016-2020.";
+pub const AUTHOR: &str = "(c) Jens Getreu, 2016-2021.";
 
 /// Title line.
 pub const TITLE: &str = "ASCII-Hangman for Kids\n";
@@ -104,7 +104,7 @@ impl HangmanBackend for Backend {
         let game = Game::new(&secret, LIVES, dict.is_empty());
         // We assume, that the configuration file comes with a custom image.
         let mut change_image = None;
-        let mut image = Image::from_formatted(config).or_else(|_| {
+        let mut image = Image::from_yaml(config).or_else(|_| {
             // We use our built-in images (first game = 0).
             change_image = Some(0);
             Image::new()
